@@ -15,11 +15,11 @@ def with_token(token):
         raise AuthenticationFailed()
 
 
-def with_email_and_password(email, password):
+def with_username_and_password(username, password):
     client = Client(base_url(), docker_host())
 
     try:
-        client.token = client.request("POST", "/signin", data={"username": email, "password": password})["token"]
+        client.token = client.request("POST", "/signin", data={"username": username, "password": password})["token"]
         client.bootstrap()
         return client
     except BadRequest:
