@@ -8,8 +8,8 @@ import logging
 log = logging.getLogger(__name__)
 
 class DockerClient(docker.Client):
-    def __init__(self, base_url, auth_token):
-        super(DockerClient, self).__init__(base_url)
+    def __init__(self, base_url, auth_token, *args, **kwargs):
+        super(DockerClient, self).__init__(base_url, *args, **kwargs)
 
         self.auth_header = "Token %s" % auth_token
         self.headers["Authorization"] = self.auth_header
